Routine User Guide
==================

This guide is designed for users who want to perform standard curve fitting analysis efficiently using NLSQ's workflow system, CLI, or GUI.

.. grid:: 2
   :gutter: 3

   .. grid-item-card:: Quick Start
      :link: tutorials/01_first_fit
      :link-type: doc

      Run your first fit in under 5 minutes.

   .. grid-item-card:: GUI
      :link: gui/index
      :link-type: doc

      Interactive curve fitting without writing code.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   tutorials/01_first_fit
   tutorials/02_understanding_results
   howto/migration
   howto/choose_model

.. toctree::
   :maxdepth: 2
   :caption: Workflow System

   howto/common_workflows
   howto/configure_yaml
   reference/configuration

.. toctree::
   :maxdepth: 2
   :caption: Interfaces

   reference/cli
   gui/index
